store_node_aes: Store node aesthetics
Description
Store the names of node attributes to use as aesthetics as graph attributes
Usage
store_node_aes(graph, node_aes_list, metadata)
Arguments
graph
graph to store attributes in
node_aes_list
nested list containing node aesthetics
metadata
data.frame containing metadata that can be used as aesthetics
Value
graph with additional attributes